@@ -141,7 +141,7 @@ class GoogleSecretManager(GoogleClientManager):
         )
 
         resource = Resource(
-            identifier=ResourceIdentifier(key="secret", name="Secret", url_slug=None),
+            identifiers=[ResourceIdentifier(key="secret", name="Secret")],
             details={"secret_name": name},
         )
 
@@ -277,7 +277,7 @@ class GoogleSecretManager(GoogleClientManager):
         executed_at = datetime.now(tz=timezone.utc)
 
         resource = Resource(
-            identifier=ResourceIdentifier(key="secret", name="Secret", url_slug=None),
+            identifiers=[ResourceIdentifier(key="secret", name="Secret")],
             details={"secret_name": name},
         )
 
